@@ -24,14 +24,20 @@ as.mxMatrix <- function(x, name, ...) {
     values[free] <- sapply(freePara2, function(x){ as.numeric(x[1])})
     labels <- matrix(NA, ncol=nCol, nrow=nRow)
     labels[free] <- sapply(freePara2, function(x){ x[2]})
+    
+    ## Replace TRUE by FALSE in free when there are definition variables
+    free[grep("data.", labels)] <- FALSE
+    
     out <- mxMatrix(type = "Full", nrow=nRow, ncol=nCol, values=values, free=free,
                     name=name, labels=labels, ...)
   } else {
     out <- mxMatrix(type = "Full", nrow=nRow, ncol=nCol, values=values, free=free,
                     name=name, ...)
   }
-  ## Add the dimnames on values
-  dimnames(out@values) <- dimnames(x)
+    
+  ## Add the dimnames for ease of references
+  dimnames(out@values) <- dimnames(out@labels) <- dimnames(out@free) <- dimnames(x)
+
   ## options(warn=warn)
   out
 }
